# The Materials Project API

[![testing](https://github.com/materialsproject/api/workflows/testing/badge.svg)](https://github.com/materialsproject/api/actions?query=workflow%3Atesting) [![codecov](https://codecov.io/gh/materialsproject/api/branch/main/graph/badge.svg)](https://codecov.io/gh/materialsproject/api) [![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/materialsproject/api.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/materialsproject/api/context:python)

This repository is the development environment for the next Materials Project API. A core server and client implementation will reside here.
